@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
-    Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -112,7 +112,7 @@ USA.
      (map (lambda (os-suffix)
 	    (string-append pkg-name "-" os-suffix))
 	  ;; XXX Need them all to process other package descriptions.
-	  '("os2" "unx" "w32"))
+	  '("unx"))
      (sort (let ((names
 		  (map ->namestring
 		       (cref/package-files
@@ -130,11 +130,6 @@ USA.
 		    (cons* (compiler-make-file)
 			   "base/make"
 			   names))
-		   ((string=? bundle "edwin")
-		    (cons* "make"
-			   "edwin"
-			   "rename"
-			   names))
 		   (else names)))
 	   string<?))))
 
